<p align="center">
    <img src="docs/figures/regius_logo.png">
</p>

[![Travis](https://img.shields.io/travis/RegiusQuant/regius.svg?)](https://travis-ci.org/RegiusQuant/regius)
[![PyPi](https://img.shields.io/pypi/v/regius-dl.svg)](https://pypi.org/project/regius-dl/)

[![Python Version](https://img.shields.io/pypi/pyversions/regius-dl.svg)](https://pypi.org/project/regius-dl/)
[![License](https://img.shields.io/pypi/l/regius-dl.svg)](https://pypi.org/project/regius-dl/)

# Regius
Regius是一个简单的深度学习工具包，用于构建图像、文本以及结构化数据模型

### 简介
Regius目前对于结构化数据采用Google的Wide&Deep模型。
模型的参考文章参见[这里](https://arxiv.org/abs/1606.07792)

### 安装
Regius基于PyTorch进行开发，安装之前需要先安装[PyTorch](https://pytorch.org/get-started/locally/)

之后通过pip进行安装
```bash
pip install regius-dl
```